dns

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LookupRecordArgs

type LookupRecordArgs struct {
	// [string] The ID of the DNS Record you want to search for.
	Id *string `pulumi:"id"`
	// [string] The name of the DNS Record you want to search for.
	Name *string `pulumi:"name"`
	// [bool] Whether partial matching is allowed or not when using name argument. Default value is false.
	//
	// Either `id` or `name` must be provided. If none, or both are provided, the datasource will return an error.
	PartialMatch *bool `pulumi:"partialMatch"`
	// [string] The ID of the DNS Zone in which the DNS Record can be found.
	ZoneId string `pulumi:"zoneId"`
}

A collection of arguments for invoking getRecord.

type LookupRecordOutputArgs

type LookupRecordOutputArgs struct {
	// [string] The ID of the DNS Record you want to search for.
	Id pulumi.StringPtrInput `pulumi:"id"`
	// [string] The name of the DNS Record you want to search for.
	Name pulumi.StringPtrInput `pulumi:"name"`
	// [bool] Whether partial matching is allowed or not when using name argument. Default value is false.
	//
	// Either `id` or `name` must be provided. If none, or both are provided, the datasource will return an error.
	PartialMatch pulumi.BoolPtrInput `pulumi:"partialMatch"`
	// [string] The ID of the DNS Zone in which the DNS Record can be found.
	ZoneId pulumi.StringInput `pulumi:"zoneId"`
}

A collection of arguments for invoking getRecord.

func (LookupRecordOutputArgs) ElementType

func (LookupRecordOutputArgs) ElementType() reflect.Type

type LookupRecordResult

type LookupRecordResult struct {
	// The content of the DNS Record.
	Content string `pulumi:"content"`
	// Indicates if the DNS Record is active or not.
	Enabled bool   `pulumi:"enabled"`
	Fqdn    string `pulumi:"fqdn"`
	// The UUID of the DNS Record.
	Id string `pulumi:"id"`
	// The name of the DNS Record.
	Name         string `pulumi:"name"`
	PartialMatch *bool  `pulumi:"partialMatch"`
	// The priority for the DNS Record.
	Priority int `pulumi:"priority"`
	// The time to live of the DNS Record.
	Ttl int `pulumi:"ttl"`
	// The type of the DNS Record.
	Type   string `pulumi:"type"`
	ZoneId string `pulumi:"zoneId"`
}

A collection of values returned by getRecord.

func LookupRecord

func LookupRecord(ctx *pulumi.Context, args *LookupRecordArgs, opts ...pulumi.InvokeOption) (*LookupRecordResult, error)

The **DNS Record** can be used to search for and return an existing DNS Record. If a single match is found, it will be returned. If your search results in multiple matches, an error will be returned. When this happens, please refine your search and make sure that your resources have unique names.

> ⚠️ Only tokens are accepted for authorization in the **ionoscloud_dns_record** data source. Please ensure you are using tokens as other methods will not be valid.

## Example Usage

### By ID

```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupRecord(ctx, &dns.LookupRecordArgs{
			Id:     pulumi.StringRef("record_id"),
			ZoneId: "zone_id",
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

### By name ```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupRecord(ctx, &dns.LookupRecordArgs{
			Name:   pulumi.StringRef("recordexample"),
			ZoneId: "zone_id",
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

### By name with partial match ```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupRecord(ctx, &dns.LookupRecordArgs{
			Name:         pulumi.StringRef("record"),
			PartialMatch: pulumi.BoolRef(true),
			ZoneId:       "zone_id",
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

type LookupRecordResultOutput

type LookupRecordResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getRecord.

func (LookupRecordResultOutput) Content

The content of the DNS Record.

func (LookupRecordResultOutput) ElementType

func (LookupRecordResultOutput) ElementType() reflect.Type

func (LookupRecordResultOutput) Enabled

Indicates if the DNS Record is active or not.

func (LookupRecordResultOutput) Fqdn

func (LookupRecordResultOutput) Id

The UUID of the DNS Record.

func (LookupRecordResultOutput) Name

The name of the DNS Record.

func (LookupRecordResultOutput) PartialMatch

func (LookupRecordResultOutput) Priority

The priority for the DNS Record.

func (LookupRecordResultOutput) ToLookupRecordResultOutput

func (o LookupRecordResultOutput) ToLookupRecordResultOutput() LookupRecordResultOutput

func (LookupRecordResultOutput) ToLookupRecordResultOutputWithContext

func (o LookupRecordResultOutput) ToLookupRecordResultOutputWithContext(ctx context.Context) LookupRecordResultOutput

func (LookupRecordResultOutput) Ttl

The time to live of the DNS Record.

func (LookupRecordResultOutput) Type

The type of the DNS Record.

func (LookupRecordResultOutput) ZoneId

type LookupZoneArgs

type LookupZoneArgs struct {
	// [string] The ID of the DNS Zone you want to search for.
	Id *string `pulumi:"id"`
	// [string] The name of the DNS Zone you want to search for.
	Name *string `pulumi:"name"`
	// [bool] Whether partial matching is allowed or not when using name argument. Default value is false.
	//
	// Either `id` or `name` must be provided. If none, or both are provided, the datasource will return an error.
	PartialMatch *bool `pulumi:"partialMatch"`
}

A collection of arguments for invoking getZone.

type LookupZoneOutputArgs

type LookupZoneOutputArgs struct {
	// [string] The ID of the DNS Zone you want to search for.
	Id pulumi.StringPtrInput `pulumi:"id"`
	// [string] The name of the DNS Zone you want to search for.
	Name pulumi.StringPtrInput `pulumi:"name"`
	// [bool] Whether partial matching is allowed or not when using name argument. Default value is false.
	//
	// Either `id` or `name` must be provided. If none, or both are provided, the datasource will return an error.
	PartialMatch pulumi.BoolPtrInput `pulumi:"partialMatch"`
}

A collection of arguments for invoking getZone.

func (LookupZoneOutputArgs) ElementType

func (LookupZoneOutputArgs) ElementType() reflect.Type

type LookupZoneResult

type LookupZoneResult struct {
	// The description of the DNS Zone.
	Description string `pulumi:"description"`
	// Indicates if the DNS Zone is activated or not.
	Enabled bool `pulumi:"enabled"`
	// The UUID of the DNS Zone.
	Id string `pulumi:"id"`
	// The name of the DNS Zone.
	Name string `pulumi:"name"`
	// A list of available name servers.
	Nameservers  []string `pulumi:"nameservers"`
	PartialMatch *bool    `pulumi:"partialMatch"`
}

A collection of values returned by getZone.

func LookupZone

func LookupZone(ctx *pulumi.Context, args *LookupZoneArgs, opts ...pulumi.InvokeOption) (*LookupZoneResult, error)

The **DNS Zone** can be used to search for and return an existing DNS Zone. If a single match is found, it will be returned. If your search results in multiple matches, an error will be returned. When this happens, please refine your search and make sure that your resources have unique names.

> ⚠️ Only tokens are accepted for authorization in the **ionoscloud_dns_zone** data source. Please ensure you are using tokens as other methods will not be valid.

## Example Usage

### By ID

```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupZone(ctx, &dns.LookupZoneArgs{
			Id: pulumi.StringRef("zone_id"),
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

### By name ```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupZone(ctx, &dns.LookupZoneArgs{
			Name: pulumi.StringRef("example.com"),
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

### By name with partial match ```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.LookupZone(ctx, &dns.LookupZoneArgs{
			Name:         pulumi.StringRef("example"),
			PartialMatch: pulumi.BoolRef(true),
		}, nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

type LookupZoneResultOutput

type LookupZoneResultOutput struct{ *pulumi.OutputState }

A collection of values returned by getZone.

func (LookupZoneResultOutput) Description

func (o LookupZoneResultOutput) Description() pulumi.StringOutput

The description of the DNS Zone.

func (LookupZoneResultOutput) ElementType

func (LookupZoneResultOutput) ElementType() reflect.Type

func (LookupZoneResultOutput) Enabled

Indicates if the DNS Zone is activated or not.

func (LookupZoneResultOutput) Id

The UUID of the DNS Zone.

func (LookupZoneResultOutput) Name

The name of the DNS Zone.

func (LookupZoneResultOutput) Nameservers

A list of available name servers.

func (LookupZoneResultOutput) PartialMatch

func (o LookupZoneResultOutput) PartialMatch() pulumi.BoolPtrOutput

func (LookupZoneResultOutput) ToLookupZoneResultOutput

func (o LookupZoneResultOutput) ToLookupZoneResultOutput() LookupZoneResultOutput

func (LookupZoneResultOutput) ToLookupZoneResultOutputWithContext

func (o LookupZoneResultOutput) ToLookupZoneResultOutputWithContext(ctx context.Context) LookupZoneResultOutput

type Record

type Record struct {
	pulumi.CustomResourceState

	// [string] The content of the DNS Record.
	Content pulumi.StringOutput `pulumi:"content"`
	// [bool] Indicates if the DNS Record is active or not. Default is `true`.
	Enabled pulumi.BoolOutput `pulumi:"enabled"`
	// Fully qualified domain name
	Fqdn pulumi.StringOutput `pulumi:"fqdn"`
	// [string] The name of the DNS Record. This property is immutable.
	Name pulumi.StringOutput `pulumi:"name"`
	// [int] The priority for the DNS Record.
	Priority pulumi.IntPtrOutput `pulumi:"priority"`
	// [int] Time to live for the DNS Record. Default is `3600`.
	Ttl pulumi.IntOutput `pulumi:"ttl"`
	// [string] The type of the DNS Record, can have one of these values: `A, AAAA, CNAME, ALIAS, MX, NS, SRV, TXT, CAA, SSHFP, TLSA, SMIMEA, DS, HTTPS, SVCB, OPENPGPKEY, CERT, URI, RP, LOC`. More details about types can be found [here](https://docs.ionos.com/cloud/network-services/cloud-dns/cloud-dns-faq#what-types-of-dns-records-does-cloud-dns-support).
	Type pulumi.StringOutput `pulumi:"type"`
	// [string] The DNS Zone ID in which the DNS Record will be created.
	ZoneId pulumi.StringOutput `pulumi:"zoneId"`
}

Manages a [DNS Record](https://docs.ionos.com/cloud/network-services/cloud-dns/overview).

> ⚠️ Only tokens are accepted for authorization in the **ionoscloud_dns_record** resource. Please ensure you are using tokens as other methods will not be valid.

## Example Usage

```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		example, err := dns.NewZone(ctx, "example", &dns.ZoneArgs{
			Name:        pulumi.String("example.com"),
			Description: pulumi.String("description"),
			Enabled:     pulumi.Bool(false),
		})
		if err != nil {
			return err
		}
		_, err = dns.NewRecord(ctx, "recordexample", &dns.RecordArgs{
			ZoneId:   example.ID(),
			Name:     pulumi.String("recordexample"),
			Type:     pulumi.String("CNAME"),
			Content:  pulumi.String("1.2.3.4"),
			Ttl:      pulumi.Int(2000),
			Priority: pulumi.Int(1024),
			Enabled:  pulumi.Bool(false),
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

In order to import a DNS Record, you can define an empty DNS Record resource in the plan: ```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.NewRecord(ctx, "example", nil)
		if err != nil {
			return err
		}
		return nil
	})
}

``` The resource can be imported using the `zoneId` and the `recordId`, for example:

```sh $ pulumi import ionoscloud:dns/record:Record example zone_id/record_id ```

func GetRecord

func GetRecord(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *RecordState, opts ...pulumi.ResourceOption) (*Record, error)

GetRecord gets an existing Record resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewRecord

func NewRecord(ctx *pulumi.Context,
	name string, args *RecordArgs, opts ...pulumi.ResourceOption) (*Record, error)

NewRecord registers a new resource with the given unique name, arguments, and options.

func (*Record) ElementType

func (*Record) ElementType() reflect.Type

func (*Record) ToRecordOutput

func (i *Record) ToRecordOutput() RecordOutput

func (*Record) ToRecordOutputWithContext

func (i *Record) ToRecordOutputWithContext(ctx context.Context) RecordOutput

type RecordArgs

type RecordArgs struct {
	// [string] The content of the DNS Record.
	Content pulumi.StringInput
	// [bool] Indicates if the DNS Record is active or not. Default is `true`.
	Enabled pulumi.BoolPtrInput
	// [string] The name of the DNS Record. This property is immutable.
	Name pulumi.StringPtrInput
	// [int] The priority for the DNS Record.
	Priority pulumi.IntPtrInput
	// [int] Time to live for the DNS Record. Default is `3600`.
	Ttl pulumi.IntPtrInput
	// [string] The type of the DNS Record, can have one of these values: `A, AAAA, CNAME, ALIAS, MX, NS, SRV, TXT, CAA, SSHFP, TLSA, SMIMEA, DS, HTTPS, SVCB, OPENPGPKEY, CERT, URI, RP, LOC`. More details about types can be found [here](https://docs.ionos.com/cloud/network-services/cloud-dns/cloud-dns-faq#what-types-of-dns-records-does-cloud-dns-support).
	Type pulumi.StringInput
	// [string] The DNS Zone ID in which the DNS Record will be created.
	ZoneId pulumi.StringInput
}

The set of arguments for constructing a Record resource.

func (RecordArgs) ElementType

func (RecordArgs) ElementType() reflect.Type

type RecordArray

type RecordArray []RecordInput

func (RecordArray) ElementType

func (RecordArray) ElementType() reflect.Type

func (RecordArray) ToRecordArrayOutput

func (i RecordArray) ToRecordArrayOutput() RecordArrayOutput

func (RecordArray) ToRecordArrayOutputWithContext

func (i RecordArray) ToRecordArrayOutputWithContext(ctx context.Context) RecordArrayOutput

type RecordArrayInput

type RecordArrayInput interface {
	pulumi.Input

	ToRecordArrayOutput() RecordArrayOutput
	ToRecordArrayOutputWithContext(context.Context) RecordArrayOutput
}

RecordArrayInput is an input type that accepts RecordArray and RecordArrayOutput values. You can construct a concrete instance of `RecordArrayInput` via:

RecordArray{ RecordArgs{...} }

type RecordArrayOutput

type RecordArrayOutput struct{ *pulumi.OutputState }

func (RecordArrayOutput) ElementType

func (RecordArrayOutput) ElementType() reflect.Type

func (RecordArrayOutput) Index

func (RecordArrayOutput) ToRecordArrayOutput

func (o RecordArrayOutput) ToRecordArrayOutput() RecordArrayOutput

func (RecordArrayOutput) ToRecordArrayOutputWithContext

func (o RecordArrayOutput) ToRecordArrayOutputWithContext(ctx context.Context) RecordArrayOutput

type RecordInput

type RecordInput interface {
	pulumi.Input

	ToRecordOutput() RecordOutput
	ToRecordOutputWithContext(ctx context.Context) RecordOutput
}

type RecordMap

type RecordMap map[string]RecordInput

func (RecordMap) ElementType

func (RecordMap) ElementType() reflect.Type

func (RecordMap) ToRecordMapOutput

func (i RecordMap) ToRecordMapOutput() RecordMapOutput

func (RecordMap) ToRecordMapOutputWithContext

func (i RecordMap) ToRecordMapOutputWithContext(ctx context.Context) RecordMapOutput

type RecordMapInput

type RecordMapInput interface {
	pulumi.Input

	ToRecordMapOutput() RecordMapOutput
	ToRecordMapOutputWithContext(context.Context) RecordMapOutput
}

RecordMapInput is an input type that accepts RecordMap and RecordMapOutput values. You can construct a concrete instance of `RecordMapInput` via:

RecordMap{ "key": RecordArgs{...} }

type RecordMapOutput

type RecordMapOutput struct{ *pulumi.OutputState }

func (RecordMapOutput) ElementType

func (RecordMapOutput) ElementType() reflect.Type

func (RecordMapOutput) MapIndex

func (RecordMapOutput) ToRecordMapOutput

func (o RecordMapOutput) ToRecordMapOutput() RecordMapOutput

func (RecordMapOutput) ToRecordMapOutputWithContext

func (o RecordMapOutput) ToRecordMapOutputWithContext(ctx context.Context) RecordMapOutput

type RecordOutput

type RecordOutput struct{ *pulumi.OutputState }

func (RecordOutput) Content

func (o RecordOutput) Content() pulumi.StringOutput

[string] The content of the DNS Record.

func (RecordOutput) ElementType

func (RecordOutput) ElementType() reflect.Type

func (RecordOutput) Enabled

func (o RecordOutput) Enabled() pulumi.BoolOutput

[bool] Indicates if the DNS Record is active or not. Default is `true`.

func (RecordOutput) Fqdn

func (o RecordOutput) Fqdn() pulumi.StringOutput

Fully qualified domain name

func (RecordOutput) Name

func (o RecordOutput) Name() pulumi.StringOutput

[string] The name of the DNS Record. This property is immutable.

func (RecordOutput) Priority

func (o RecordOutput) Priority() pulumi.IntPtrOutput

[int] The priority for the DNS Record.

func (RecordOutput) ToRecordOutput

func (o RecordOutput) ToRecordOutput() RecordOutput

func (RecordOutput) ToRecordOutputWithContext

func (o RecordOutput) ToRecordOutputWithContext(ctx context.Context) RecordOutput

func (RecordOutput) Ttl

func (o RecordOutput) Ttl() pulumi.IntOutput

[int] Time to live for the DNS Record. Default is `3600`.

func (RecordOutput) Type

func (o RecordOutput) Type() pulumi.StringOutput

[string] The type of the DNS Record, can have one of these values: `A, AAAA, CNAME, ALIAS, MX, NS, SRV, TXT, CAA, SSHFP, TLSA, SMIMEA, DS, HTTPS, SVCB, OPENPGPKEY, CERT, URI, RP, LOC`. More details about types can be found [here](https://docs.ionos.com/cloud/network-services/cloud-dns/cloud-dns-faq#what-types-of-dns-records-does-cloud-dns-support).

func (RecordOutput) ZoneId

func (o RecordOutput) ZoneId() pulumi.StringOutput

[string] The DNS Zone ID in which the DNS Record will be created.

type RecordState

type RecordState struct {
	// [string] The content of the DNS Record.
	Content pulumi.StringPtrInput
	// [bool] Indicates if the DNS Record is active or not. Default is `true`.
	Enabled pulumi.BoolPtrInput
	// Fully qualified domain name
	Fqdn pulumi.StringPtrInput
	// [string] The name of the DNS Record. This property is immutable.
	Name pulumi.StringPtrInput
	// [int] The priority for the DNS Record.
	Priority pulumi.IntPtrInput
	// [int] Time to live for the DNS Record. Default is `3600`.
	Ttl pulumi.IntPtrInput
	// [string] The type of the DNS Record, can have one of these values: `A, AAAA, CNAME, ALIAS, MX, NS, SRV, TXT, CAA, SSHFP, TLSA, SMIMEA, DS, HTTPS, SVCB, OPENPGPKEY, CERT, URI, RP, LOC`. More details about types can be found [here](https://docs.ionos.com/cloud/network-services/cloud-dns/cloud-dns-faq#what-types-of-dns-records-does-cloud-dns-support).
	Type pulumi.StringPtrInput
	// [string] The DNS Zone ID in which the DNS Record will be created.
	ZoneId pulumi.StringPtrInput
}

func (RecordState) ElementType

func (RecordState) ElementType() reflect.Type

type Zone

type Zone struct {
	pulumi.CustomResourceState

	// [string] The description for the DNS Zone.
	Description pulumi.StringPtrOutput `pulumi:"description"`
	// [bool] Indicates if the DNS Zone is active or not. Default is `true`.
	Enabled pulumi.BoolOutput `pulumi:"enabled"`
	// [string] The name of the DNS Zone. This property is immutable.
	Name pulumi.StringOutput `pulumi:"name"`
	// A list of available name servers.
	Nameservers pulumi.StringArrayOutput `pulumi:"nameservers"`
}

Manages a **DNS Zone**.

> ⚠️ Only tokens are accepted for authorization in the **ionoscloud_dns_zone** resource. Please ensure you are using tokens as other methods will not be valid.

## Example Usage

```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.NewZone(ctx, "example", &dns.ZoneArgs{
			Name:        pulumi.String("example.com"),
			Description: pulumi.String("description"),
			Enabled:     pulumi.Bool(false),
		})
		if err != nil {
			return err
		}
		return nil
	})
}

```

## Import

In order to import a DNS Zone, you can define an empty DNS Zone resource in the plan:

```go package main

import (

"github.com/ionos-cloud/pulumi-ionoscloud/sdk/go/ionoscloud/dns"
"github.com/pulumi/pulumi/sdk/v3/go/pulumi"

)

func main() {
	pulumi.Run(func(ctx *pulumi.Context) error {
		_, err := dns.NewZone(ctx, "example", nil)
		if err != nil {
			return err
		}
		return nil
	})
}

```

The resource can be imported using the `zoneId`, for example:

```sh terraform import ionoscloud_dns_zone.examplezone_id ```

func GetZone

func GetZone(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *ZoneState, opts ...pulumi.ResourceOption) (*Zone, error)

GetZone gets an existing Zone resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewZone

func NewZone(ctx *pulumi.Context,
	name string, args *ZoneArgs, opts ...pulumi.ResourceOption) (*Zone, error)

NewZone registers a new resource with the given unique name, arguments, and options.

func (*Zone) ElementType

func (*Zone) ElementType() reflect.Type

func (*Zone) ToZoneOutput

func (i *Zone) ToZoneOutput() ZoneOutput

func (*Zone) ToZoneOutputWithContext

func (i *Zone) ToZoneOutputWithContext(ctx context.Context) ZoneOutput

type ZoneArgs

type ZoneArgs struct {
	// [string] The description for the DNS Zone.
	Description pulumi.StringPtrInput
	// [bool] Indicates if the DNS Zone is active or not. Default is `true`.
	Enabled pulumi.BoolPtrInput
	// [string] The name of the DNS Zone. This property is immutable.
	Name pulumi.StringPtrInput
}

The set of arguments for constructing a Zone resource.

func (ZoneArgs) ElementType

func (ZoneArgs) ElementType() reflect.Type

type ZoneArray

type ZoneArray []ZoneInput

func (ZoneArray) ElementType

func (ZoneArray) ElementType() reflect.Type

func (ZoneArray) ToZoneArrayOutput

func (i ZoneArray) ToZoneArrayOutput() ZoneArrayOutput

func (ZoneArray) ToZoneArrayOutputWithContext

func (i ZoneArray) ToZoneArrayOutputWithContext(ctx context.Context) ZoneArrayOutput

type ZoneArrayInput

type ZoneArrayInput interface {
	pulumi.Input

	ToZoneArrayOutput() ZoneArrayOutput
	ToZoneArrayOutputWithContext(context.Context) ZoneArrayOutput
}

ZoneArrayInput is an input type that accepts ZoneArray and ZoneArrayOutput values. You can construct a concrete instance of `ZoneArrayInput` via:

ZoneArray{ ZoneArgs{...} }

type ZoneArrayOutput

type ZoneArrayOutput struct{ *pulumi.OutputState }

func (ZoneArrayOutput) ElementType

func (ZoneArrayOutput) ElementType() reflect.Type

func (ZoneArrayOutput) Index

func (ZoneArrayOutput) ToZoneArrayOutput

func (o ZoneArrayOutput) ToZoneArrayOutput() ZoneArrayOutput

func (ZoneArrayOutput) ToZoneArrayOutputWithContext

func (o ZoneArrayOutput) ToZoneArrayOutputWithContext(ctx context.Context) ZoneArrayOutput

type ZoneInput

type ZoneInput interface {
	pulumi.Input

	ToZoneOutput() ZoneOutput
	ToZoneOutputWithContext(ctx context.Context) ZoneOutput
}

type ZoneMap

type ZoneMap map[string]ZoneInput

func (ZoneMap) ElementType

func (ZoneMap) ElementType() reflect.Type

func (ZoneMap) ToZoneMapOutput

func (i ZoneMap) ToZoneMapOutput() ZoneMapOutput

func (ZoneMap) ToZoneMapOutputWithContext

func (i ZoneMap) ToZoneMapOutputWithContext(ctx context.Context) ZoneMapOutput

type ZoneMapInput

type ZoneMapInput interface {
	pulumi.Input

	ToZoneMapOutput() ZoneMapOutput
	ToZoneMapOutputWithContext(context.Context) ZoneMapOutput
}

ZoneMapInput is an input type that accepts ZoneMap and ZoneMapOutput values. You can construct a concrete instance of `ZoneMapInput` via:

ZoneMap{ "key": ZoneArgs{...} }

type ZoneMapOutput

type ZoneMapOutput struct{ *pulumi.OutputState }

func (ZoneMapOutput) ElementType

func (ZoneMapOutput) ElementType() reflect.Type

func (ZoneMapOutput) MapIndex

func (ZoneMapOutput) ToZoneMapOutput

func (o ZoneMapOutput) ToZoneMapOutput() ZoneMapOutput

func (ZoneMapOutput) ToZoneMapOutputWithContext

func (o ZoneMapOutput) ToZoneMapOutputWithContext(ctx context.Context) ZoneMapOutput

type ZoneOutput

type ZoneOutput struct{ *pulumi.OutputState }

func (ZoneOutput) Description

func (o ZoneOutput) Description() pulumi.StringPtrOutput

[string] The description for the DNS Zone.

func (ZoneOutput) ElementType

func (ZoneOutput) ElementType() reflect.Type

func (ZoneOutput) Enabled

func (o ZoneOutput) Enabled() pulumi.BoolOutput

[bool] Indicates if the DNS Zone is active or not. Default is `true`.

func (ZoneOutput) Name

func (o ZoneOutput) Name() pulumi.StringOutput

[string] The name of the DNS Zone. This property is immutable.

func (ZoneOutput) Nameservers

func (o ZoneOutput) Nameservers() pulumi.StringArrayOutput

A list of available name servers.

func (ZoneOutput) ToZoneOutput

func (o ZoneOutput) ToZoneOutput() ZoneOutput

func (ZoneOutput) ToZoneOutputWithContext

func (o ZoneOutput) ToZoneOutputWithContext(ctx context.Context) ZoneOutput

type ZoneState

type ZoneState struct {
	// [string] The description for the DNS Zone.
	Description pulumi.StringPtrInput
	// [bool] Indicates if the DNS Zone is active or not. Default is `true`.
	Enabled pulumi.BoolPtrInput
	// [string] The name of the DNS Zone. This property is immutable.
	Name pulumi.StringPtrInput
	// A list of available name servers.
	Nameservers pulumi.StringArrayInput
}

func (ZoneState) ElementType

func (ZoneState) ElementType() reflect.Type

Jump to